@@ -13,8 +13,8 @@
 """
 #################################################################
 ##      ___  ___       ___   _   __   _      ___     __    __  ##
-##     /   |/   |     /   | | | |  \ | |    |    \  \  \  /  / ##
-##    / /|   /| |    / /| | | | |   \| |    |     |  \  \/  /  ##
+##     /   |/   |     /   | | | |  \ | |    |  _ \  \  \  /  / ##
+##    / /|   /| |    / /| | | | |   \| |    | |_| |  \  \/  /  ##
 ##   / / |__/ | |   / / | | | | | |\   |    |  __/    \    /   ##
 ##  / /       | |  / /  | | | | | | \  |    | |       /   /    ##
 ## /_/        |_| /_/   |_| |_| |_|  \_| ⬤ |_|      /__ /     ##
@@ -834,6 +834,10 @@ def spreadsheet(screen_width,screen_height):
     editUndo.setShortcut(QKeySequence("Ctrl+Z"))
     editUndo.triggered.connect(lambda:tableWidget.model().undo())
 
+    editRedo = edit.addAction('Redo')
+    editRedo.setShortcut(QKeySequence("Ctrl+Shift+Z"))
+    editRedo.triggered.connect(lambda:tableWidget.model().redo())
+
     editCut= edit.addAction("cu&t")
     editCut.setShortcut(QKeySequence("Ctrl+X"))
     #editCut.triggered.connect(cutCopyPasteHandler)
@@ -875,10 +879,19 @@ def spreadsheet(screen_width,screen_height):
     viewStyle.addAction('Fusion')
     viewStyle.addAction('Windows')
 
+    def changeTheme(theme):
+        if theme == 'dark':
+            mainWidget.setStyleSheet('background-color:#2f2f35; color:white;')
+        elif theme == 'lite':
+            mainWidget.setStyleSheet('background-color:white; color:black;')
+        elif theme == 'system':
+            mainWidget.setStyleSheet('')
+        changeSettings('theme',theme)
+
     viewTheme = view.addMenu('Theme')
-    viewTheme.addAction('Dark').triggered.connect(lambda : mainWidget.setStyleSheet('background-color:#2f2f35; color:white;') | changeSettings('theme','dark'))
-    viewTheme.addAction('Lite').triggered.connect(lambda : mainWidget.setStyleSheet('background-color:white; color:black;') | changeSettings('theme','lite'))
-    viewTheme.addAction('System').triggered.connect(lambda: mainWidget.setStyleSheet('') | changeSettings('theme','system'))
+    viewTheme.addAction('Dark').triggered.connect(lambda : changeTheme('dark'))
+    viewTheme.addAction('Lite').triggered.connect(lambda : changeTheme('lite'))
+    viewTheme.addAction('System').triggered.connect(lambda: changeTheme('system'))
 
 
     
@@ -935,6 +948,13 @@ def spreadsheet(screen_width,screen_height):
         json = f.read()
     json = json_loads(json) # convert json to dict
 
+    if 'font' in json:
+        fontTypeCB.setCurrentText(json['font'])
+    if 'fontsize' in json:
+        fontSizeCB.setCurrentText(json['fontsize'])
+    if 'theme' in json:
+        changeTheme(json['theme'])
+
 
     return table_tab_box # return the main layout
 
@@ -960,6 +980,13 @@ def spreadsheet(screen_width,screen_height):
 def main():
     global plt_setting, saved_file, current_file_name, settings, mainWidget
 
+    if '-help' in sys.argv or '--help' in sys.argv:
+        print("""Usage: py-office-sheet [<option>...]
+py-office-sheet cross-platform spreadsheet based on pandas and numpy for effecient data processing\n
+for more information, visit https://github.com/YC-Lammy/py-office-sheet
+
+        """)
+        return 0
     saved_file = True #state if the file is modified, notice user to save file
     current_file_name = None #current file name is the file user opened using open file function
     plt_setting = {'set':False}
